@@ -245,6 +245,44 @@ from bitmovin_api_sdk.models.dolby_atmos_ingest_input_stream import DolbyAtmosIn
 from bitmovin_api_sdk.models.dolby_atmos_input_format import DolbyAtmosInputFormat
 from bitmovin_api_sdk.models.dolby_atmos_loudness_control import DolbyAtmosLoudnessControl
 from bitmovin_api_sdk.models.dolby_atmos_metering_mode import DolbyAtmosMeteringMode
+from bitmovin_api_sdk.models.dolby_digital_audio_configuration import DolbyDigitalAudioConfiguration
+from bitmovin_api_sdk.models.dolby_digital_bitstream_info import DolbyDigitalBitstreamInfo
+from bitmovin_api_sdk.models.dolby_digital_center_mix_level import DolbyDigitalCenterMixLevel
+from bitmovin_api_sdk.models.dolby_digital_channel_layout import DolbyDigitalChannelLayout
+from bitmovin_api_sdk.models.dolby_digital_dialogue_intelligence import DolbyDigitalDialogueIntelligence
+from bitmovin_api_sdk.models.dolby_digital_downmixing import DolbyDigitalDownmixing
+from bitmovin_api_sdk.models.dolby_digital_downmixing_preferred_mode import DolbyDigitalDownmixingPreferredMode
+from bitmovin_api_sdk.models.dolby_digital_dynamic_range_compression import DolbyDigitalDynamicRangeCompression
+from bitmovin_api_sdk.models.dolby_digital_dynamic_range_compression_mode import DolbyDigitalDynamicRangeCompressionMode
+from bitmovin_api_sdk.models.dolby_digital_evolution_framework_control import DolbyDigitalEvolutionFrameworkControl
+from bitmovin_api_sdk.models.dolby_digital_lfe_low_pass_filter import DolbyDigitalLfeLowPassFilter
+from bitmovin_api_sdk.models.dolby_digital_loudness_control import DolbyDigitalLoudnessControl
+from bitmovin_api_sdk.models.dolby_digital_loudness_control_mode import DolbyDigitalLoudnessControlMode
+from bitmovin_api_sdk.models.dolby_digital_loudness_control_regulation_type import DolbyDigitalLoudnessControlRegulationType
+from bitmovin_api_sdk.models.dolby_digital_ninety_degree_phase_shift import DolbyDigitalNinetyDegreePhaseShift
+from bitmovin_api_sdk.models.dolby_digital_plus_audio_configuration import DolbyDigitalPlusAudioConfiguration
+from bitmovin_api_sdk.models.dolby_digital_plus_bitstream_info import DolbyDigitalPlusBitstreamInfo
+from bitmovin_api_sdk.models.dolby_digital_plus_center_mix_level import DolbyDigitalPlusCenterMixLevel
+from bitmovin_api_sdk.models.dolby_digital_plus_channel_layout import DolbyDigitalPlusChannelLayout
+from bitmovin_api_sdk.models.dolby_digital_plus_dialogue_intelligence import DolbyDigitalPlusDialogueIntelligence
+from bitmovin_api_sdk.models.dolby_digital_plus_downmixing import DolbyDigitalPlusDownmixing
+from bitmovin_api_sdk.models.dolby_digital_plus_downmixing_preferred_mode import DolbyDigitalPlusDownmixingPreferredMode
+from bitmovin_api_sdk.models.dolby_digital_plus_dynamic_range_compression import DolbyDigitalPlusDynamicRangeCompression
+from bitmovin_api_sdk.models.dolby_digital_plus_dynamic_range_compression_mode import DolbyDigitalPlusDynamicRangeCompressionMode
+from bitmovin_api_sdk.models.dolby_digital_plus_evolution_framework_control import DolbyDigitalPlusEvolutionFrameworkControl
+from bitmovin_api_sdk.models.dolby_digital_plus_lfe_low_pass_filter import DolbyDigitalPlusLfeLowPassFilter
+from bitmovin_api_sdk.models.dolby_digital_plus_loudness_control import DolbyDigitalPlusLoudnessControl
+from bitmovin_api_sdk.models.dolby_digital_plus_loudness_control_mode import DolbyDigitalPlusLoudnessControlMode
+from bitmovin_api_sdk.models.dolby_digital_plus_loudness_control_regulation_type import DolbyDigitalPlusLoudnessControlRegulationType
+from bitmovin_api_sdk.models.dolby_digital_plus_ninety_degree_phase_shift import DolbyDigitalPlusNinetyDegreePhaseShift
+from bitmovin_api_sdk.models.dolby_digital_plus_preprocessing import DolbyDigitalPlusPreprocessing
+from bitmovin_api_sdk.models.dolby_digital_plus_surround_mix_level import DolbyDigitalPlusSurroundMixLevel
+from bitmovin_api_sdk.models.dolby_digital_plus_surround_mode import DolbyDigitalPlusSurroundMode
+from bitmovin_api_sdk.models.dolby_digital_plus_three_db_attenuation import DolbyDigitalPlusThreeDbAttenuation
+from bitmovin_api_sdk.models.dolby_digital_preprocessing import DolbyDigitalPreprocessing
+from bitmovin_api_sdk.models.dolby_digital_surround_mix_level import DolbyDigitalSurroundMixLevel
+from bitmovin_api_sdk.models.dolby_digital_surround_mode import DolbyDigitalSurroundMode
+from bitmovin_api_sdk.models.dolby_digital_three_db_attenuation import DolbyDigitalThreeDbAttenuation
 from bitmovin_api_sdk.models.dolby_vision_metadata import DolbyVisionMetadata
 from bitmovin_api_sdk.models.dolby_vision_metadata_ingest_input_stream import DolbyVisionMetadataIngestInputStream
 from bitmovin_api_sdk.models.dolby_vision_metadata_source import DolbyVisionMetadataSource
