@@ -18,6 +18,8 @@ class CodecConfigType(Enum):
     MP3 = "MP3"
     AC3 = "AC3"
     EAC3 = "EAC3"
+    DD = "DD"
+    DDPLUS = "DDPLUS"
     OPUS = "OPUS"
     VORBIS = "VORBIS"
     MJPEG = "MJPEG"
